from .core import route

__all__ = "route"
